%define major     %(echo %{version}|cut -d. -f1,2)
%define iconname  sylpheed.png

%define libapi    0
%define libmajor  1
%define libname   %mklibname %name %libapi %libmajor
%define develname %mklibname %name -d

Summary:	A GTK+2 based, lightweight, and fast e-mail client
Name:		sylpheed
Version:	3.7.0
Release:	%mkrel 10
Group:		Networking/Mail
License:	GPLv2
URL:		https://sylpheed.sraoss.jp/
Source0:	https://sylpheed.sraoss.jp/sylpheed/v%{major}/sylpheed-%{version}.tar.bz2
# https://bugs.mageia.org/show_bug.cgi?id=29356
# CVE-2021-37746
Patch1:		sylpheed-3.7.0-uri-check.patch
# various type and format related fixes
Patch5:		sylpheed-3.7.0-types.patch 
BuildRequires:	gettext-devel
BuildRequires:	gtk+2-devel >= 2.8.0
BuildRequires:	gpgme-devel > 1.0.0
BuildRequires:	pkgconfig(openssl)
BuildRequires:	imagemagick
BuildRequires:	libpilot-link-devel
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(gtkspell-2.0)

Requires:	curl
Provides:	sylpheed-main = %{version}-%{release}
Provides:	sylpheed2 = %{version}-%{release}

%description
This program is an X based fast e-mail client which has features
(or go for it :-)) like:
	o user-friendly and intuitive interface
	o integrated NetNews client (partially implemented)
	o ability of keyboard-only operation
	o Mew/Wanderlust-like key bind
	o multipart MIME
	o built-in image view
	o external editor support
	o unlimited multiple account handling
	o message queueing
	o filtering
	o XML-based address book
See 'README' for more information.

%package -n %libname
Summary:	Library files for %name
Group:		Networking/Mail

%description -n %libname
This package contains shared library files for %name.

%package -n %develname
Summary:	Development files for %name
Group:		Networking/Mail
Requires:	%libname = %version
Provides:	%name-devel = %version-%release

%description -n %develname
This package contains development files for %name.

%prep
%autosetup -p1

#switch to enchant2
sed -i -e '/PKG_CONFIG/s,enchant,enchant-2,g' configure.ac
sed -i -e 's,<enchant/enchant.h>,<enchant-2/enchant.h>,g' src/compose.c

%build
%global optflags %{optflags} -std=gnu17

autoreconf -vfi -Iac
%configure      --enable-gpgme \
		--enable-jpilot \
		--enable-ssl \
		--enable-ldap \
		--enable-ipv6
%make_build

%install
%make_install

mkdir -p %{buildroot}{%{_miconsdir},%{_iconsdir},%{_liconsdir}}
magick sylpheed.png -geometry 48x48 %{buildroot}%{_liconsdir}/%{iconname}
magick sylpheed.png -geometry 32x32 %{buildroot}%{_iconsdir}/%{iconname}
magick sylpheed.png -geometry 16x16 %{buildroot}%{_miconsdir}/%{iconname}

%{find_lang} %name

%files -f %{name}.lang
%doc AUTHORS ChangeLog* NEWS README* TODO*
%{_bindir}/*
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/faq
%lang(de) %doc %{_datadir}/%{name}/faq/de
%lang(en) %doc %{_datadir}/%{name}/faq/en
%lang(es) %doc %{_datadir}/%{name}/faq/es
%lang(fr) %doc %{_datadir}/%{name}/faq/fr
%lang(it) %doc %{_datadir}/%{name}/faq/it
%dir %{_datadir}/%{name}/manual
%lang(en) %doc %{_datadir}/%{name}/manual/en
%lang(ja) %doc %{_datadir}/%{name}/manual/ja
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}.png
%{_iconsdir}/%{iconname}
%{_liconsdir}/%{iconname}
%{_miconsdir}/%{iconname}

%files -n %libname
%{_libdir}/*-%{libapi}.so.%{libmajor}{,.*}

%files -n %develname
%{_libdir}/*.so
%{_includedir}/%{name}


%changelog
* Sat May 24 2025 daviddavid <daviddavid> 3.7.0-10.mga10
+ Revision: 2186167
- fix build with gcc 15 using -std=gnu17

* Sat Oct 26 2024 daviddavid <daviddavid> 3.7.0-9.mga10
+ Revision: 2111321
- add fedora patch to fix build with GCC 14
- really apply patch for CVE-2021-37746

* Tue Jan 03 2023 umeabot <umeabot> 3.7.0-8.mga9
+ Revision: 1929562
- Rebuild to use libldap-2.5 instead of 2.4

* Mon Apr 04 2022 umeabot <umeabot> 3.7.0-7.mga9
+ Revision: 1843770
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 3.7.0-6.mga9
+ Revision: 1747485
- rebuild for openssl 3.0.0

* Wed Aug 11 2021 wally <wally> 3.7.0-5.mga9
+ Revision: 1741084
- add fedora patch to fix CVE-2021-37746 (mga#29356)
- clean old obsoletes/provides

* Sat Feb 15 2020 umeabot <umeabot> 3.7.0-4.mga8
+ Revision: 1523194
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Feb 23 2019 wally <wally> 3.7.0-3.mga7
+ Revision: 1369584
- switch to enchant2

* Sun Sep 23 2018 umeabot <umeabot> 3.7.0-2.mga7
+ Revision: 1301270
- Mageia 7 Mass Rebuild

* Mon Apr 23 2018 daviddavid <daviddavid> 3.7.0-1.mga7
+ Revision: 1221340
- new version: 3.7.0

* Fri Oct 13 2017 mrambo3501 <mrambo3501> 3.6.0-1.mga7
+ Revision: 1171652
- version 3.6.0

* Tue Sep 05 2017 cjw <cjw> 3.5.0-3.mga7
+ Revision: 1151582
- rebuild for openssl 1.1

* Thu Mar 03 2016 umeabot <umeabot> 3.5.0-2.mga6
+ Revision: 984152
- Rebuild for openssl

* Thu Jan 28 2016 fwang <fwang> 3.5.0-1.mga6
+ Revision: 928330
- 3.5.0

* Wed Oct 15 2014 umeabot <umeabot> 3.4.2-3.mga5
+ Revision: 750140
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.4.2-2.mga5
+ Revision: 689649
- Mageia 5 Mass Rebuild

* Wed Jun 11 2014 fwang <fwang> 3.4.2-1.mga5
+ Revision: 635577
- 3.4.2

* Sat Apr 05 2014 fwang <fwang> 3.4.1-1.mga5
+ Revision: 611972
- 3.4.1

* Mon Mar 10 2014 fwang <fwang> 3.3.1-1.mga5
+ Revision: 601637
- 3.3.1

* Fri Oct 18 2013 umeabot <umeabot> 3.3.0-4.mga4
+ Revision: 519429
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 3.3.0-3.mga3
+ Revision: 383873
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 13 2012 fwang <fwang> 3.3.0-2.mga3
+ Revision: 317290
- br gtkspell

* Sat Nov 10 2012 fwang <fwang> 3.3.0-1.mga3
+ Revision: 316832
- new version 3.3.0

* Fri Jun 29 2012 fwang <fwang> 3.2.0-1.mga3
+ Revision: 264917
- new version 3.2.0

* Wed Jun 06 2012 fwang <fwang> 3.1.4-1.mga3
+ Revision: 256135
- new version 3.1.4

* Thu Mar 01 2012 fwang <fwang> 3.1.3-1.mga2
+ Revision: 216377
- fix build with latest glib
- new version 3.1.3

* Thu Sep 08 2011 fwang <fwang> 3.1.2-1.mga2
+ Revision: 141361
- new version 3.1.2

* Sun Jun 19 2011 kharec <kharec> 3.1.1-1.mga2
+ Revision: 109688
- new version 3.1.1

* Tue Feb 01 2011 dmorgan <dmorgan> 3.1.0-1.mga1
+ Revision: 46057
- Remove mdv macros
- imported package sylpheed


* Mon Jan 31 2011 Funda Wang <fwang@mandriva.org> 3.1.0-1mdv2011.0
+ Revision: 634509
- New version 3.1.0

* Tue Oct 26 2010 Franck Villaume <fvill@mandriva.com> 3.0.3-3mdv2011.0
+ Revision: 589512
- disable gtkspell due to segfault

* Tue Oct 26 2010 Franck Villaume <fvill@mandriva.com> 3.0.3-2mdv2011.0
+ Revision: 589433
- enable gtkspell support

* Sun Jul 18 2010 Funda Wang <fwang@mandriva.org> 3.0.3-1mdv2011.0
+ Revision: 554845
- update to new version 3.0.3

* Mon Apr 12 2010 Funda Wang <fwang@mandriva.org> 3.0.2-2mdv2010.1
+ Revision: 533643
- rebuild

* Fri Apr 02 2010 Funda Wang <fwang@mandriva.org> 3.0.2-1mdv2010.1
+ Revision: 530774
- update to new version 3.0.2

* Thu Mar 18 2010 Funda Wang <fwang@mandriva.org> 3.0.1-1mdv2010.1
+ Revision: 524760
- update to new version 3.0.1

* Wed Feb 24 2010 Funda Wang <fwang@mandriva.org> 3.0.0-1mdv2010.1
+ Revision: 510687
- update file list
- new version 3.0.0

* Sat Aug 15 2009 Funda Wang <fwang@mandriva.org> 2.7.1-1mdv2010.0
+ Revision: 416431
- fix file list
- new version 2.7.1

* Sat Dec 20 2008 Funda Wang <fwang@mandriva.org> 2.6.0-1mdv2009.1
+ Revision: 316397
- New version 2.6.0

* Wed Jun 18 2008 Funda Wang <fwang@mandriva.org> 2.5.0-1mdv2009.0
+ Revision: 225368
- New version 2.5.0 final

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Fri Jun 06 2008 Funda Wang <fwang@mandriva.org> 2.5.0-0.rc2.1mdv2009.0
+ Revision: 216477
- New version 2.5.0rc2

* Tue May 20 2008 Funda Wang <fwang@mandriva.org> 2.5.0-0.rc.1mdv2009.0
+ Revision: 209575
- add missing files
- New version 2.5.0rc

* Sat Jan 05 2008 Jérôme Soyer <saispo@mandriva.org> 2.4.8-1mdv2008.1
+ Revision: 145870
- New release

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Oct 14 2007 Funda Wang <fwang@mandriva.org> 2.4.7-1mdv2008.1
+ Revision: 98226
- fix desktop file
- corrected license
- New version 2.4.7

* Fri Aug 31 2007 Funda Wang <fwang@mandriva.org> 2.4.5-1mdv2008.0
+ Revision: 76745
- New version 2.4.5

* Mon Jul 23 2007 Funda Wang <fwang@mandriva.org> 2.4.4-1mdv2008.0
+ Revision: 54535
- New version

* Tue Jul 03 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.3-1mdv2008.0
+ Revision: 47647
- Updated to version 2.4.3.

* Mon May 21 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.2-1mdv2008.0
+ Revision: 29256
- Updated to 2.4.2.

* Tue May 08 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.1-1mdv2008.0
+ Revision: 25062
- Updated to 2.4.1.
- Updated BuildRequires.


* Wed Jan 03 2007 Jérôme Soyer <saispo@mandriva.org> 2.3.0-1mdv2007.0
+ Revision: 103662
- Add BuildRequires
- New release 2.3.0
- New release 2.2.10
- Import sylpheed

* Wed Sep 06 2006 Frederic Crozat <fcrozat@mandriva.com> 2.2.7-2mdv2007.0
- Rebuild with latest pilot-link

* Thu Aug 03 2006 Charles A Edwards <eslrahc@mandriva.org> 2.2.7-1mdv2007.0
- 2.2.7
- xdg

* Wed Jun 14 2006 Charles A Edwards <eslrahc@mandriva.org> 2.2.6-1mdv2007.0
-2.2.6

* Sun Apr 02 2006 Jerome Soyer <saispo@mandriva.org> 2.2.4-1mdk
- New release 2.2.4

* Tue Mar 14 2006 Jerome Soyer <saispo@mandriva.org> 2.2.3-1mdk
- New release 2.2.3

* Wed Mar 08 2006 Jerome Soyer <saispo@mandriva.org> 2.2.2-1mdk
- New release 2.2.2

* Tue Feb 28 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.1-1mdk
- 2.2.1.

* Sat Jan 21 2006 Marcel Pol <mpol@mandriva.org> 2.2.0-0.beta4.3mdk
- buildrequires gpgme-devel (on 32 and 64 bit)

* Wed Jan 18 2006 Marcel Pol <mpol@mandriva.org> 2.2.0-0.beta4.2mdk
- buildrequires libgpgme-devel > 0.4.5

* Fri Jan 13 2006 Marcel Pol <mpol@mandriva.org> 2.2.0-0.beta4.1mdk
- 2.2.0beta4

* Sat Dec 03 2005 Marcel Pol <mpol@mandriva.org> 2.1.8-1mdk
- 2.1.8

* Sat Oct 22 2005 Stefan van der Eijk <stefan@eijk.nu> 2.1.4-2mdk
- BuildRequires

* Fri Oct 21 2005 Marcel Pol <mpol@mandriva.org> 2.1.4-1mdk
- 2.1.4
- don't conflict with sylpheed-claws, parallel installable now

* Tue Oct 18 2005 Marcel Pol <mpol@mandriva.org> 2.1.3-1mdk
- 2.1.3
- merge changes from sylpheed2 package (mostly buildrequires)
- provide and obsolete sylpheed2

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 1.0.5-2mdk
- rebuilt against new openldap-2.3.6 libs

* Fri Jul 29 2005 Marcel Pol <mpol@mandriva.org> 1.0.5-1mdk
- 1.0.5
- %%mkrel

* Fri Mar 25 2005 Charles A Edwards <eslrahc@mandrake.org> 1.0.4-1mdk
- 1.0.4

* Fri Mar 04 2005 Charles A Edwards <eslrahc@mandrake.org> 1.0.3-1mdk
- 1.0.3

* Thu Feb 03 2005 Charles A Edwards <eslrahc@mandrake.org> 1.0.1-1mdk
- 1.0.1
- BR gpgme >= 0.4.5..now supports gpgme-1.0
- enable ipv6 support

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.0.0-2mdk
- rebuild for new readline
- cosmetics

* Mon Dec 27 2004 Charles A Edwards <eslrahc@mandrake.org> 1.0.0-1mdk
- new release

* Sat Dec 04 2004 Charles A Edwards <eslrahc@mandrake.org> 1.0.0-0.beta4.1mdk
- 1.0.0beta4

* Tue Nov 09 2004 Charles A Edwards <eslrahc@mandrake.org> 1.0.0-0.beta2.1mdk
- 1.0.0beta2
- add version to libgpgme BR
- disable ipv6

* Sun May 30 2004 Charles A Edwards <eslrahc@mandrake.org> 0.9.11-1mdk
- 0.9.11
- rm buildroot in %%install instead of %%prep
- rm ldap fix--no longer needed

* Tue Mar 02 2004 Charles A Edwards <eslrahc@mandrake.org> 0.9.10-1mdk
- 0.9.10
- work around for ldap (Tibor Pittich)
- menu entry

* Fri Jan 30 2004 Charles A Edwards <eslrahc@mandrake.org> 0.9.9-1mdk
- 0.9.9
- adjust buildrequires for libgpgme-devel

